==> hoteldruid-mod-id_3.0.6-1.tar.gz: id/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Nama depan akan diubah dari"; break;
case "a":  					$messaggio = "menjadi"; break;
case "Il nome verrà cambiato da":  		$messaggio = "Nama belakang akan diubah dari"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "Gender akan diubah dari "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "Tanggal lahir akan diubah dari"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Telepon akan diubah dari"; break;
case "La via  verrà cambiata da":  		$messaggio = "Alamat akan diubah dari"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "No Alamat akan diubah dari"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "Kota tinggal akan diubah dari"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "Negara akan diubah dari"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "Kode pos akan diubah dari"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Fax akan diubah dari"; break;
case "L' email verrà cambiata da":  		$messaggio = "Email akan diubah dari"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = " <b>Keterangan</b> akan diubah menjadi"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = " <b>nama</b> akan dihapus"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = " <b>tanggal lahir</b> akan dihapus"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = " <b>telephone</b> akan dihapus"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = " <b>alamat</b> akan dihapus"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = " <b>no alamat</b> akan dihapus"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = " <b>kota</b> akan dihapus"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = " <b>negara</b> akan dihapus"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "The <b>kode pos</b> akan dihapus"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "The <b>fax</b> akan dihapus"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "The <b>email</b> akan dihapus"; break;
case "Continua":  				$messaggio = "Lanjut"; break;
case "Il cliente":  				$messaggio = "Klien"; break;
case "è stato modificato":  			$messaggio = "sudah diubah"; break;
case "Torna indietro":  			$messaggio = "Kembali"; break;
case "Modifica i dati del cliente":  		$messaggio = "Ubah data klien"; break;
case "Cognome":  				$messaggio = "Nama depan"; break;
case "cambia in":  				$messaggio = "ubah menjadi"; break;
case "Nome":  					$messaggio = "Nama belakang"; break;
case "cancella":  				$messaggio = "hapus"; break;
case "Data di nascita":  			$messaggio = "Tanggal lahir"; break;
case "Via":  					$messaggio = "Alamat"; break;
case "Vicolo":  				$messaggio = "Jalan"; break;
case "Numero civico":  				$messaggio = "Nomor"; break;
case "Città di residenza":  			$messaggio = "Kota"; break;
case "Nazione di residenza":  			$messaggio = "Negara"; break;
case "CAP":  					$messaggio = "Kode pos"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Commento":  				$messaggio = "Keterangan"; break;
case "documento di tipo":  			$messaggio = "tipe dokumen"; break;
case "visualizza":  				$messaggio = "lihat"; break;
case "visualizza il documento":  		$messaggio = "lihat dokumen"; break;
case "Prenotazioni del cliente":  		$messaggio = "Klien reservasi"; break;
case "nel":  					$messaggio = "in"; break;
case "Cognome_del_cliente":  			$messaggio = "Nama depan klien"; break;
case "Data_iniziale":  				$messaggio = "Tanggal awal"; break;
case "Data_finale":  				$messaggio = "Tanggal akhir"; break;
case "Tariffa_completa":  			$messaggio = "Harga lengkap"; break;
case "Pagato":  				$messaggio = "Bayar"; break;
case "Commento":  				$messaggio = "Keterangan"; break;
case "Inserito da":  				$messaggio = "Ditambahkan oleh"; break;
case "Cliente cancellato":  			$messaggio = "Klien dihapus"; break;
case "Cancella il cliente":  			$messaggio = "Hapus klien"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Klien tidak dapat dihapus karena dia masih ada reservasi yang terkait"; break;
case "NO":  					$messaggio = "TIDAK"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Apa anda yakin untuk <div style=\"display: inline; color: red;\">menghapus</div> klien"; break;
case "SI":  					$messaggio = "YA"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Kabupaten"; break;
case "Documento":  				$messaggio = "Dokumen"; break;
case "Scadenza documento":  			$messaggio = "Masa berlaku dokumen"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "Kabupaten akan diubah dari"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Dokumen akan diubah dari"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "Masa berlaku dokumen akan diubah dari"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = " <b>Kabupaten</b> akan dihapus"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "The <b>dokumen</b> akan dihapus"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = " <b>masa berlaku dokumen</b> akan dihapus"; break;
case "Cittadinanza":  				$messaggio = "Kewarganegaraan"; break;
case "Nazione di nascita":  			$messaggio = "Negara asal"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Kabupaten asal"; break;
case "Città di nascita":  			$messaggio = "Kota"; break;
case "Città di rilascio":  			$messaggio = "Kota penerbitan"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Kabupaten penerbitan"; break;
case "Nazione di rilascio":  			$messaggio = "Negara penerbitan"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "Kewarganegaraan akan diubah dari"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "Negara akan diubah dari"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "Kabupaten akan diubah dari"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "Kota akan diubah dari"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "Kota penerbitan akan diubah dari"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "Kabupaten akan diubah dari"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "Negara akan diubah dari"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = " <b>Kewarganegaraan</b> akan dihapus"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>negara asal</b> akan dihapus"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>kabupaten asal</b> akan dihapus"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>kota asal</b> akan dihapus"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>kota penerbitan</b> akan dihapus"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>kabupaten penerbitan</b> akan dihapus"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>negara penerbitan</b> akan dihapus"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "Kode fiskal akan diubah dari"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> akan dihapus"; break;
case "Titolo":  				$messaggio = "Gelar"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "Gelar akan diubah dari"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = " <b>gelar</b> akan dihapus"; break;
case "La partita iva verrà cambiata da":  	$messaggio = " VAT number akan diubah dari"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = " <b>VAT number</b> akan dihapus"; break;
case "data inserimento":  			$messaggio = "tanggal penambahan"; break;
case "carte di credito":  			$messaggio = "kartu kredit klien"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password untuk melihat kartu kredit"; break;
case "invia":  					$messaggio = "kirim"; break;
case "password errata":  			$messaggio = "password salah"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "data kartu kredit dihapus"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "nomor kartu kredit <span class=\"colred\">salah</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "Nomor CVC <span class=\"colred\">salah</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "data kartu kredit ditambahkan"; break;
case "carta di credito del cliente":  		$messaggio = "kartu kredit klien"; break;
case "Tipo":  					$messaggio = "Jenis"; break;
case "Scadenza":  				$messaggio = "Masa berlaku"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "modifica i dati della carta di credito":	$messaggio = "ubah data kartu kredit"; break;
case "cancella questa carta di credito":  	$messaggio = "hapus kartu kredit ini"; break;
case "soprannome":  				$messaggio = "nama panggilan"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "Nama panggilan akan diubah dari"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>Nama Panggilan</b> akan dihapus"; break;
case "La lingua verrà cambiata da":  		$messaggio = "Bahasa akan diubah dari"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "<b>Bahasa</b> akan dihapus"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Data kartu kredit dapat dilihat hanya pada koneksi yang aman"; break;
case "verrà tolto":  				$messaggio = "akan dihapus"; break;
case "verrà modificato":  			$messaggio = "akan diubah"; break;
case "verrà aggiunto":  			$messaggio = "akan ditambah"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "The 2nd telephone will be changed from"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "The 3rd telephone will be changed from"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "The <b>2nd telephone</b> will be deleted"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "The <b>3rd telephone</b> will be deleted"; break;
case "Sesso":  					$messaggio = "Gender"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Email":  					$messaggio = "Email"; break;
case "2° telefono":  				$messaggio = "2nd telephone"; break;
case "3° telefono":  				$messaggio = "3rd telephone"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Si considererà l'utente":  		$messaggio = "User"; break;
case "come colui che ha inserito il cliente":	$messaggio = "will be considered as the one who inserted the client"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-id_3.0.8-1.tar.gz: id/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Nama depan akan diubah dari"; break;
case "a":  					$messaggio = "menjadi"; break;
case "Il nome verrà cambiato da":  		$messaggio = "Nama belakang akan diubah dari"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "Gender akan diubah dari "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "Tanggal lahir akan diubah dari"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Telepon akan diubah dari"; break;
case "La via  verrà cambiata da":  		$messaggio = "Alamat akan diubah dari"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "No Alamat akan diubah dari"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "Kota tinggal akan diubah dari"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "Negara akan diubah dari"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "Kode pos akan diubah dari"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Fax akan diubah dari"; break;
case "L' email verrà cambiata da":  		$messaggio = "Email akan diubah dari"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = " <b>Keterangan</b> akan diubah menjadi"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = " <b>nama</b> akan dihapus"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = " <b>tanggal lahir</b> akan dihapus"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = " <b>telephone</b> akan dihapus"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = " <b>alamat</b> akan dihapus"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = " <b>no alamat</b> akan dihapus"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = " <b>kota</b> akan dihapus"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = " <b>negara</b> akan dihapus"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "The <b>kode pos</b> akan dihapus"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "The <b>fax</b> akan dihapus"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "The <b>email</b> akan dihapus"; break;
case "Continua":  				$messaggio = "Lanjut"; break;
case "Il cliente":  				$messaggio = "Klien"; break;
case "è stato modificato":  			$messaggio = "sudah diubah"; break;
case "Torna indietro":  			$messaggio = "Kembali"; break;
case "Modifica i dati del cliente":  		$messaggio = "Ubah data klien"; break;
case "Cognome":  				$messaggio = "Nama depan"; break;
case "cambia in":  				$messaggio = "ubah menjadi"; break;
case "Nome":  					$messaggio = "Nama belakang"; break;
case "cancella":  				$messaggio = "hapus"; break;
case "Data di nascita":  			$messaggio = "Tanggal lahir"; break;
case "Via":  					$messaggio = "Alamat"; break;
case "Vicolo":  				$messaggio = "Jalan"; break;
case "Numero civico":  				$messaggio = "Nomor"; break;
case "Città di residenza":  			$messaggio = "Kota"; break;
case "Nazione di residenza":  			$messaggio = "Negara"; break;
case "CAP":  					$messaggio = "Kode pos"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Commento":  				$messaggio = "Keterangan"; break;
case "documento di tipo":  			$messaggio = "tipe dokumen"; break;
case "visualizza":  				$messaggio = "lihat"; break;
case "visualizza il documento":  		$messaggio = "lihat dokumen"; break;
case "Prenotazioni del cliente":  		$messaggio = "Klien reservasi"; break;
case "nel":  					$messaggio = "in"; break;
case "Cognome_del_cliente":  			$messaggio = "Nama depan klien"; break;
case "Data_iniziale":  				$messaggio = "Tanggal awal"; break;
case "Data_finale":  				$messaggio = "Tanggal akhir"; break;
case "Tariffa_completa":  			$messaggio = "Harga lengkap"; break;
case "Pagato":  				$messaggio = "Bayar"; break;
case "Commento":  				$messaggio = "Keterangan"; break;
case "Inserito da":  				$messaggio = "Ditambahkan oleh"; break;
case "Cliente cancellato":  			$messaggio = "Klien dihapus"; break;
case "Cancella il cliente":  			$messaggio = "Hapus klien"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Klien tidak dapat dihapus karena dia masih ada reservasi yang terkait"; break;
case "NO":  					$messaggio = "TIDAK"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Apa anda yakin untuk <div style=\"display: inline; color: red;\">menghapus</div> klien"; break;
case "SI":  					$messaggio = "YA"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Kabupaten"; break;
case "Documento":  				$messaggio = "Dokumen"; break;
case "Scadenza documento":  			$messaggio = "Masa berlaku dokumen"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "Kabupaten akan diubah dari"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Dokumen akan diubah dari"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "Masa berlaku dokumen akan diubah dari"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = " <b>Kabupaten</b> akan dihapus"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "The <b>dokumen</b> akan dihapus"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = " <b>masa berlaku dokumen</b> akan dihapus"; break;
case "Cittadinanza":  				$messaggio = "Kewarganegaraan"; break;
case "Nazione di nascita":  			$messaggio = "Negara asal"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Kabupaten asal"; break;
case "Città di nascita":  			$messaggio = "Kota"; break;
case "Città di rilascio":  			$messaggio = "Kota penerbitan"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Kabupaten penerbitan"; break;
case "Nazione di rilascio":  			$messaggio = "Negara penerbitan"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "Kewarganegaraan akan diubah dari"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "Negara akan diubah dari"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "Kabupaten akan diubah dari"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "Kota akan diubah dari"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "Kota penerbitan akan diubah dari"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "Kabupaten akan diubah dari"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "Negara akan diubah dari"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = " <b>Kewarganegaraan</b> akan dihapus"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>negara asal</b> akan dihapus"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>kabupaten asal</b> akan dihapus"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>kota asal</b> akan dihapus"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>kota penerbitan</b> akan dihapus"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>kabupaten penerbitan</b> akan dihapus"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>negara penerbitan</b> akan dihapus"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "Kode fiskal akan diubah dari"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> akan dihapus"; break;
case "Titolo":  				$messaggio = "Gelar"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "Gelar akan diubah dari"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = " <b>gelar</b> akan dihapus"; break;
case "La partita iva verrà cambiata da":  	$messaggio = " VAT number akan diubah dari"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = " <b>VAT number</b> akan dihapus"; break;
case "data inserimento":  			$messaggio = "tanggal penambahan"; break;
case "carte di credito":  			$messaggio = "kartu kredit klien"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password untuk melihat kartu kredit"; break;
case "invia":  					$messaggio = "kirim"; break;
case "password errata":  			$messaggio = "password salah"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "data kartu kredit dihapus"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "nomor kartu kredit <span class=\"colred\">salah</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "Nomor CVC <span class=\"colred\">salah</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "data kartu kredit ditambahkan"; break;
case "carta di credito del cliente":  		$messaggio = "kartu kredit klien"; break;
case "Tipo":  					$messaggio = "Jenis"; break;
case "Scadenza":  				$messaggio = "Masa berlaku"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "modifica i dati della carta di credito":	$messaggio = "ubah data kartu kredit"; break;
case "cancella questa carta di credito":  	$messaggio = "hapus kartu kredit ini"; break;
case "soprannome":  				$messaggio = "nama panggilan"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "Nama panggilan akan diubah dari"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>Nama Panggilan</b> akan dihapus"; break;
case "La lingua verrà cambiata da":  		$messaggio = "Bahasa akan diubah dari"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "<b>Bahasa</b> akan dihapus"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Data kartu kredit dapat dilihat hanya pada koneksi yang aman"; break;
case "verrà tolto":  				$messaggio = "akan dihapus"; break;
case "verrà modificato":  			$messaggio = "akan diubah"; break;
case "verrà aggiunto":  			$messaggio = "akan ditambah"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "The 2nd telephone will be changed from"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "The 3rd telephone will be changed from"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "The <b>2nd telephone</b> will be deleted"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "The <b>3rd telephone</b> will be deleted"; break;
case "Sesso":  					$messaggio = "Gender"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Email":  					$messaggio = "Email"; break;
case "2° telefono":  				$messaggio = "2nd telephone"; break;
case "3° telefono":  				$messaggio = "3rd telephone"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Si considererà l'utente":  		$messaggio = "User"; break;
case "come colui che ha inserito il cliente":	$messaggio = "will be considered as the one who inserted the client"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
